test

Function test 

pub fn test(o: VerifiedCommand) -> Result<()>
Describes CLI commands. Run all tests run tests in specified crate Describes CLI commands. Run all tests run tests in specified crate run tests in specified crate

Errors

qqq: doc