Genera-purpose tools which might be moved out one day. Work with paths.
Modules
- exposed
- Exposed namespace of the module.
- kw
- Keywords
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *. - proc_
macro2 - github crates-io docs-rs
- quote
- github crates-io docs-rs
- syn
- github crates-io docs-rs
Macros
- quote
- The whole point.
Traits
- Iter
Trait - Trait that encapsulates a clonable iterator with specific characteristics.