pub struct PathSegment {
pub ident: Ident,
pub arguments: PathArguments,
}Expand description
A segment of a path together with any path arguments on that segment.
Fields
ident: Identarguments: PathArgumentsTrait Implementations
Sourceimpl Clone for PathSegment
Available on crate features derive or full only.
impl Clone for PathSegment
Available on crate features
derive or full only.Sourcefn clone(&self) -> PathSegment
fn clone(&self) -> PathSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PathSegment
Available on crate features derive or full only.
impl Debug for PathSegment
Available on crate features
derive or full only.impl Eq for PathSegment
Available on crate features
derive or full only.Sourceimpl<T> From<T> for PathSegment
impl<T> From<T> for PathSegment
Sourcefn from(ident: T) -> PathSegment
fn from(ident: T) -> PathSegment
Converts to this type from the input type.
Sourceimpl Hash for PathSegment
Available on crate features derive or full only.
impl Hash for PathSegment
Available on crate features
derive or full only.Sourceimpl Parse for PathSegment
impl Parse for PathSegment
fn parse(input: &ParseBuffer<'_>) -> Result<PathSegment, Error>
Sourceimpl PartialEq for PathSegment
Available on crate features derive or full only.
impl PartialEq for PathSegment
Available on crate features
derive or full only.Sourcefn eq(&self, other: &PathSegment) -> bool
fn eq(&self, other: &PathSegment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToTokens for PathSegment
impl ToTokens for PathSegment
Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,