pub struct TraitItemConst {
pub attrs: Vec<Attribute>,
pub const_token: Const,
pub ident: Ident,
pub generics: Generics,
pub colon_token: Colon,
pub ty: Type,
pub default: Option<(Eq, Expr)>,
pub semi_token: Semi,
}Expand description
An associated constant within the definition of a trait.
Fields
attrs: Vec<Attribute>const_token: Constident: Identgenerics: Genericscolon_token: Colonty: Typedefault: Option<(Eq, Expr)>semi_token: SemiTrait Implementations
Sourceimpl Clone for TraitItemConst
Available on crate feature full only.
impl Clone for TraitItemConst
Available on crate feature
full only.Sourcefn clone(&self) -> TraitItemConst
fn clone(&self) -> TraitItemConst
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraitItemConst
Available on crate feature full only.
impl Debug for TraitItemConst
Available on crate feature
full only.impl Eq for TraitItemConst
Available on crate feature
full only.Sourceimpl From<TraitItemConst> for TraitItem
impl From<TraitItemConst> for TraitItem
Sourcefn from(e: TraitItemConst) -> TraitItem
fn from(e: TraitItemConst) -> TraitItem
Converts to this type from the input type.
Sourceimpl Hash for TraitItemConst
Available on crate feature full only.
impl Hash for TraitItemConst
Available on crate feature
full only.Sourceimpl Parse for TraitItemConst
impl Parse for TraitItemConst
fn parse(input: &ParseBuffer<'_>) -> Result<TraitItemConst, Error>
Sourceimpl PartialEq for TraitItemConst
Available on crate feature full only.
impl PartialEq for TraitItemConst
Available on crate feature
full only.Sourcefn eq(&self, other: &TraitItemConst) -> bool
fn eq(&self, other: &TraitItemConst) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToTokens for TraitItemConst
impl ToTokens for TraitItemConst
Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,