Module tree

Module tree 

Genera-purpose tools which might be moved out one day. Tools for printing a tree

Modules

exposed
Exposed namespace of the module.
orphan
Orphan namespace of the module.
own
Own namespace of the module.
prelude
Prelude to use essentials: use my_module ::prelude :: *.

Structs

ListNodeReport
Represents a node in a dependency graph. It holds essential information about the project dependencies. It is also capable of holding any nested dependencies in a recursive manner, allowing the modeling of complex dependency structures.
TreePrinter
Struct for formatting and printing tree-like structures. It contains symbols used for visualizing the tree and information about the tree nodes.